==> kubernetes-model-admissionregistration-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1beta1/ResourceRuleBuilder.java <==
package io.fabric8.kubernetes.api.model.authorization.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ResourceRuleBuilder extends io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRuleFluentImpl<io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRuleBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule,io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRuleBuilder>{
  public ResourceRuleBuilder() {
    this(false);
  }
  public ResourceRuleBuilder(java.lang.Boolean validationEnabled) {
    this(new ResourceRule(), validationEnabled);
  }
  public ResourceRuleBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRuleFluent<?> fluent) {
    this(fluent, false);
  }
  public ResourceRuleBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRuleFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ResourceRule(), validationEnabled);
  }
  public ResourceRuleBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRuleFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule instance) {
    this(fluent, instance, false);
  }
  public ResourceRuleBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRuleFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiGroups(instance.getApiGroups()); 
    fluent.withResourceNames(instance.getResourceNames()); 
    fluent.withResources(instance.getResources()); 
    fluent.withVerbs(instance.getVerbs()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ResourceRuleBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule instance) {
    this(instance,false);
  }
  public ResourceRuleBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiGroups(instance.getApiGroups()); 
    this.withResourceNames(instance.getResourceNames()); 
    this.withResources(instance.getResources()); 
    this.withVerbs(instance.getVerbs()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRuleFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule build() {
    ResourceRule buildable = new ResourceRule(fluent.getApiGroups(),fluent.getResourceNames(),fluent.getResources(),fluent.getVerbs());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ResourceRuleBuilder that = (ResourceRuleBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-admissionregistration-6.3.0-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1beta1/ResourceRuleBuilder.java <==
package io.fabric8.kubernetes.api.model.authorization.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ResourceRuleBuilder extends ResourceRuleFluentImpl<ResourceRuleBuilder> implements VisitableBuilder<ResourceRule,ResourceRuleBuilder>{
  public ResourceRuleBuilder() {
    this(false);
  }
  public ResourceRuleBuilder(Boolean validationEnabled) {
    this(new ResourceRule(), validationEnabled);
  }
  public ResourceRuleBuilder(ResourceRuleFluent<?> fluent) {
    this(fluent, false);
  }
  public ResourceRuleBuilder(ResourceRuleFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ResourceRule(), validationEnabled);
  }
  public ResourceRuleBuilder(ResourceRuleFluent<?> fluent,ResourceRule instance) {
    this(fluent, instance, false);
  }
  public ResourceRuleBuilder(ResourceRuleFluent<?> fluent,ResourceRule instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiGroups(instance.getApiGroups()); 
    fluent.withResourceNames(instance.getResourceNames()); 
    fluent.withResources(instance.getResources()); 
    fluent.withVerbs(instance.getVerbs()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ResourceRuleBuilder(ResourceRule instance) {
    this(instance,false);
  }
  public ResourceRuleBuilder(ResourceRule instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiGroups(instance.getApiGroups()); 
    this.withResourceNames(instance.getResourceNames()); 
    this.withResources(instance.getResources()); 
    this.withVerbs(instance.getVerbs()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ResourceRuleFluent<?> fluent;
  Boolean validationEnabled;
  public ResourceRule build() {
    ResourceRule buildable = new ResourceRule(fluent.getApiGroups(),fluent.getResourceNames(),fluent.getResources(),fluent.getVerbs());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
